
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.features.access.access import AccessUI

web.site_root = AccessUI
